@@ -70,7 +70,7 @@ def disassociate_floating_ip(self, context, instance, address):
     except exception.Forbidden:
         raise webob.exc.HTTPForbidden()
     except exception.CannotDisassociateAutoAssignedFloatingIP:
-        msg = _('Cannot disassociate auto assigned floating ip')
+        msg = _('Cannot disassociate auto assigned floating IP')
         raise webob.exc.HTTPForbidden(explanation=msg)
 
 
@@ -83,20 +83,20 @@ class FloatingIPController(object):
         super(FloatingIPController, self).__init__()
 
     def show(self, req, id):
-        """Return data about the given floating ip."""
+        """Return data about the given floating IP."""
         context = req.environ['nova.context']
         authorize(context)
 
         try:
             floating_ip = self.network_api.get_floating_ip(context, id)
         except (exception.NotFound, exception.InvalidID):
-            msg = _("Floating ip not found for id %s") % id
+            msg = _("Floating IP not found for ID %s") % id
             raise webob.exc.HTTPNotFound(explanation=msg)
 
         return _translate_floating_ip_view(floating_ip)
 
     def index(self, req):
-        """Return a list of floating ips allocated to a project."""
+        """Return a list of floating IPs allocated to a project."""
         context = req.environ['nova.context']
         authorize(context)
 
@@ -116,9 +116,9 @@ class FloatingIPController(object):
             ip = self.network_api.get_floating_ip_by_address(context, address)
         except exception.NoMoreFloatingIps:
             if pool:
-                msg = _("No more floating ips in pool %s.") % pool
+                msg = _("No more floating IPs in pool %s.") % pool
             else:
-                msg = _("No more floating ips available.")
+                msg = _("No more floating IPs available.")
             raise webob.exc.HTTPNotFound(explanation=msg)
         except exception.FloatingIpLimitExceeded:
             if pool:
@@ -141,7 +141,7 @@ class FloatingIPController(object):
         try:
             floating_ip = self.network_api.get_floating_ip(context, id)
         except (exception.NotFound, exception.InvalidID):
-            msg = _("Floating ip not found for id %s") % id
+            msg = _("Floating IP not found for ID %s") % id
             raise webob.exc.HTTPNotFound(explanation=msg)
         address = floating_ip['address']
 
@@ -153,7 +153,7 @@ class FloatingIPController(object):
         except exception.Forbidden:
             raise webob.exc.HTTPForbidden()
         except exception.CannotDisassociateAutoAssignedFloatingIP:
-            msg = _('Cannot disassociate auto assigned floating ip')
+            msg = _('Cannot disassociate auto assigned floating IP')
             raise webob.exc.HTTPForbidden(explanation=msg)
         return webob.Response(status_int=202)
 
@@ -184,14 +184,14 @@ class FloatingIPActionController(wsgi.Controller):
         cached_nwinfo = compute_utils.get_nw_info_for_instance(instance)
         if not cached_nwinfo:
             LOG.warning(
-                _LW('Info cache is %r during associate') % instance.info_cache,
+                _LW('Info cache is %r during associate'), instance.info_cache,
                 instance=instance)
             msg = _('No nw_info cache associated with instance')
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
         fixed_ips = cached_nwinfo.fixed_ips()
         if not fixed_ips:
-            msg = _('No fixed ips associated to instance')
+            msg = _('No fixed IPs associated to instance')
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
         fixed_address = None
@@ -210,7 +210,7 @@ class FloatingIPActionController(wsgi.Controller):
                 fixed_address = next(ip['address'] for ip in fixed_ips
                                      if netaddr.valid_ipv4(ip['address']))
             except StopIteration:
-                msg = _('Unable to associate floating ip %(address)s '
+                msg = _('Unable to associate floating IP %(address)s '
                         'to any fixed IPs for instance %(id)s. '
                         'Instance has no fixed IPv4 addresses to '
                         'associate.') % (
@@ -225,19 +225,19 @@ class FloatingIPActionController(wsgi.Controller):
                                   floating_address=address,
                                   fixed_address=fixed_address)
         except exception.FloatingIpAssociated:
-            msg = _('floating ip is already associated')
+            msg = _('floating IP is already associated')
             raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.NoFloatingIpInterface:
-            msg = _('l3driver call to add floating ip failed')
+            msg = _('l3driver call to add floating IP failed')
             raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.FloatingIpNotFoundForAddress:
-            msg = _('floating ip not found')
+            msg = _('floating IP not found')
             raise webob.exc.HTTPNotFound(explanation=msg)
         except exception.Forbidden as e:
             raise webob.exc.HTTPForbidden(explanation=e.format_message())
         except Exception as e:
-            msg = _('Unable to associate floating ip %(address)s to '
-                    'fixed ip %(fixed_address)s for instance %(id)s. '
+            msg = _('Unable to associate floating IP %(address)s to '
+                    'fixed IP %(fixed_address)s for instance %(id)s. '
                     'Error: %(error)s') % (
                     {'address': address, 'fixed_address': fixed_address,
                      'id': id, 'error': e})
@@ -266,7 +266,7 @@ class FloatingIPActionController(wsgi.Controller):
             floating_ip = self.network_api.get_floating_ip_by_address(context,
                                                                       address)
         except exception.FloatingIpNotFoundForAddress:
-            msg = _("floating ip not found")
+            msg = _("floating IP not found")
             raise webob.exc.HTTPNotFound(explanation=msg)
 
         # get the associated instance object (if any)
@@ -281,11 +281,11 @@ class FloatingIPActionController(wsgi.Controller):
             try:
                 disassociate_floating_ip(self, context, instance, address)
             except exception.FloatingIpNotAssociated:
-                msg = _('Floating ip is not associated')
+                msg = _('Floating IP is not associated')
                 raise webob.exc.HTTPBadRequest(explanation=msg)
             return webob.Response(status_int=202)
         else:
-            msg = _("Floating ip %(address)s is not associated with instance "
+            msg = _("Floating IP %(address)s is not associated with instance "
                     "%(id)s.") % {'address': address, 'id': id}
             raise webob.exc.HTTPConflict(explanation=msg)
 
