@@ -15,9 +15,12 @@
 
 """The virtual interfaces extension."""
 
+import webob
+
 from nova.api.openstack import common
 from nova.api.openstack import extensions
 from nova import compute
+from nova.i18n import _
 from nova import network
 
 
@@ -46,7 +49,12 @@ class ServerVirtualInterfaceController(object):
         context = req.environ['nova.context']
         instance = common.get_instance(self.compute_api, context, server_id)
 
-        vifs = self.network_api.get_vifs_by_instance(context, instance)
+        try:
+            vifs = self.network_api.get_vifs_by_instance(context, instance)
+        except NotImplementedError:
+            msg = _('Listing virtual interfaces is not supported by this '
+                    'cloud.')
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         limited_list = common.limited(vifs, req)
         res = [entity_maker(vif) for vif in limited_list]
         return {'virtual_interfaces': res}
