@@ -124,6 +124,8 @@ class VolumeController(wsgi.Controller):
 
         try:
             self.volume_api.delete(context, id)
+        except exception.InvalidInput as e:
+            raise exc.HTTPBadRequest(explanation=e.format_message())
         except exception.NotFound as e:
             raise exc.HTTPNotFound(explanation=e.format_message())
         return webob.Response(status_int=202)
@@ -323,6 +325,8 @@ class VolumeAttachmentController(wsgi.Controller):
             raise exc.HTTPNotFound(explanation=e.format_message())
         except exception.InstanceIsLocked as e:
             raise exc.HTTPConflict(explanation=e.format_message())
+        except exception.DevicePathInUse as e:
+            raise exc.HTTPConflict(explanation=e.format_message())
         except exception.InstanceInvalidState as state_error:
             common.raise_http_conflict_for_instance_invalid_state(state_error,
                     'attach_volume', server_id)
@@ -365,8 +369,19 @@ class VolumeAttachmentController(wsgi.Controller):
         except KeyError:
             msg = _("volumeId must be specified.")
             raise exc.HTTPBadRequest(explanation=msg)
+
         self._validate_volume_id(new_volume_id)
-        new_volume = self.volume_api.get(context, new_volume_id)
+        try:
+            new_volume = self.volume_api.get(context, new_volume_id)
+        except exception.VolumeNotFound as e:
+            # NOTE: This BadRequest is different from the above NotFound even
+            # though the same VolumeNotFound exception. This is intentional
+            # because new_volume_id is specified in a request body and if a
+            # nonexistent resource in the body (not URI) the code should be
+            # 400 Bad Request as API-WG guideline. On the other hand,
+            # old_volume_id is specified with URI. So it is valid to return
+            # NotFound response if that is not existent.
+            raise exc.HTTPBadRequest(explanation=e.format_message())
 
         instance = common.get_instance(self.compute_api, context, server_id)
 
