@@ -21,6 +21,7 @@ import sys
 
 import six
 
+import nova.conf
 from nova import objects
 from nova.objects import base as obj_base
 
@@ -35,6 +36,8 @@ BLOCK_SYNC_FLAG = '!!'
 # Separator used between cell name and item
 _CELL_ITEM_SEP = '@'
 
+CONF = nova.conf.CONF
+
 
 class ProxyObjectSerializer(obj_base.NovaObjectSerializer):
     def __init__(self):
@@ -100,10 +103,10 @@ class _CellProxy(object):
                 else:
                     yield name, getattr(self._obj, name)
 
-    if six.PY3:
-        items = _iteritems
-    else:
+    if six.PY2:
         iteritems = _iteritems
+    else:
+        items = _iteritems
 
     def __getattr__(self, key):
         return getattr(self._obj, key)
@@ -131,6 +134,19 @@ def get_instances_to_sync(context, updated_since=None, project_id=None,
     cells services aren't self-healing the same instances in nearly
     lockstep.
     """
+    def _get_paginated_instances(context, filters, shuffle, limit, marker):
+        instances = objects.InstanceList.get_by_filters(
+                context, filters, sort_key='deleted', sort_dir='asc',
+                limit=limit, marker=marker)
+        if len(instances) > 0:
+            marker = instances[-1]['uuid']
+            # NOTE(melwitt/alaski): Need a list that supports assignment for
+            # shuffle.  And pop() on the returned result.
+            instances = list(instances)
+            if shuffle:
+                random.shuffle(instances)
+        return instances, marker
+
     filters = {}
     if updated_since is not None:
         filters['changes-since'] = updated_since
@@ -139,13 +155,17 @@ def get_instances_to_sync(context, updated_since=None, project_id=None,
     if not deleted:
         filters['deleted'] = False
     # Active instances first.
-    instances = objects.InstanceList.get_by_filters(
-            context, filters, sort_key='deleted', sort_dir='asc')
-    if shuffle:
-        # NOTE(melwitt): Need a list that supports assignment for shuffle.
-        instances = [instance for instance in instances]
-        random.shuffle(instances)
-    for instance in instances:
+    limit = CONF.cells.instance_update_sync_database_limit
+    marker = None
+
+    instances = []
+    while True:
+        if not instances:
+            instances, marker = _get_paginated_instances(context, filters,
+                    shuffle, limit, marker)
+        if not instances:
+            break
+        instance = instances.pop(0)
         if uuids_only:
             yield instance.uuid
         else:
