@@ -25,8 +25,11 @@ import sys
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+import six
 
 from nova import config
+from nova import exception
+from nova.i18n import _LE, _LW
 from nova import objects
 from nova import service
 from nova import utils
@@ -42,12 +45,26 @@ def main():
     logging.setup(CONF, "nova")
     utils.monkey_patch()
     objects.register_all()
+    log = logging.getLogger(__name__)
 
     gmr.TextGuruMeditation.setup_autorun(version)
 
     launcher = service.process_launcher()
+    started = 0
     for api in CONF.enabled_apis:
         should_use_ssl = api in CONF.enabled_ssl_apis
-        server = service.WSGIService(api, use_ssl=should_use_ssl)
-        launcher.launch_service(server, workers=server.workers or 1)
+        try:
+            server = service.WSGIService(api, use_ssl=should_use_ssl)
+            launcher.launch_service(server, workers=server.workers or 1)
+            started += 1
+        except exception.PasteAppNotFound as ex:
+            log.warning(
+                _LW("%s. ``enabled_apis`` includes bad values. "
+                    "Fix to remove this warning."), six.text_type(ex))
+
+    if started == 0:
+        log.error(_LE('No APIs were started. '
+                      'Check the enabled_apis config option.'))
+        sys.exit(1)
+
     launcher.wait()
