@@ -36,6 +36,7 @@ IRONIC = "ironic"
 KQEMU = "kqemu"
 KVM = "kvm"
 LXC = "lxc"
+LXD = "lxd"
 OPENVZ = "openvz"
 PARALLELS = "parallels"
 VIRTUOZZO = "vz"
@@ -58,6 +59,7 @@ ALL = (
     KQEMU,
     KVM,
     LXC,
+    LXD,
     OPENVZ,
     PARALLELS,
     PHYP,
